@@ -47,6 +47,7 @@ extern const char* get_documents_path(char* file);
 
 int __saved = 0;
 
+extern char *cfile;
 bool accel_move;
 PcsxConfig Config;
 R3000Acpu *psxCpu;
@@ -250,6 +251,10 @@ accel_move=false;
 
 	CheckCdrom();
 
+	// If a state has been specified, then load that
+	if (loadst) 
+		LoadState(cfile);
+
 	//if (file != NULL) Load(file);
 	//else
 	{
