@@ -313,7 +313,7 @@ HGLRC GLCONTEXT=NULL;
 #define MODE_X11 1
 #define MODE_SDL 2
 int pandora_driver_mode = MODE_RAW;
-int use_fsaa = 0;
+int use_fsaa;
 
 EGLDisplay display;
 EGLConfig  config;
@@ -336,7 +336,7 @@ Colormap        x11Colormap	= 0;
 EGLint attrib_list_fsaa[] =
 {
 	EGL_SURFACE_TYPE, EGL_WINDOW_BIT,
-	EGL_BUFFER_SIZE,    0,
+	EGL_BUFFER_SIZE,    16,
 	EGL_DEPTH_SIZE,     16,
 	EGL_SAMPLE_BUFFERS, 1,
 	EGL_SAMPLES,        4,
@@ -346,7 +346,7 @@ EGLint attrib_list_fsaa[] =
 EGLint attrib_list[] =
 {
 	EGL_SURFACE_TYPE, EGL_WINDOW_BIT,
-	EGL_BUFFER_SIZE,  0,
+	EGL_BUFFER_SIZE,  16,
 	EGL_DEPTH_SIZE,   16,
 	EGL_NONE
 };
@@ -389,7 +389,7 @@ void maemoGLinit(){
 #endif
 	
 	EGLint *attribList = NULL;
-	if (use_fsaa)
+	if (use_fsaa==1)
 	{
 		printf( "GLES: Using Full Scene Antialiasing\n" );
 		attribList = attrib_list_fsaa;
