@@ -547,6 +547,34 @@ void osd_close_display (void)                          // close display
 }
 
 ////////////////////////////////////////////////////////////////////////
+bool TestEGLError(const char* pszLocation)
+{
+	/*
+		eglGetError returns the last error that has happened using egl,
+		not the status of the last called function. The user has to
+		check after every single egl call or at least once every frame.
+	*/
+	EGLint iErr = eglGetError();
+	if (iErr != EGL_SUCCESS)
+	{
+		printf("%s failed (%d).\n", pszLocation, iErr);
+		return false;
+	}
+
+	return true;
+}
+
+
+
+
+  EGLConfig   iEglConfig;  
+  EGLConfig	   eglConfig	= 0;
+  EGLint numConfigs;
+  EGLSurface			eglSurface	= 0;
+ EGLDisplay			eglDisplay	= 0;
+
+
+
 
 void sysdep_create_display(void)                       // create display
 {
@@ -557,130 +585,211 @@ void sysdep_create_display(void)                       // create display
  MotifWmHints mwmhints;Atom mwmatom;Atom delwindow;
  char *glxfx;
 
- glxfx=getenv("MESA_GLX_FX");                          // 3dfx mesa fullscreen flag
- if(glxfx)
-  {
-   if(glxfx[0]=='f')                                   // -> yup, fullscreen needed
-    {
-     fx=1;                                             // -> raise flag
-     putenv("FX_GLIDE_NO_SPLASH=");
-     sprintf(gammastr,"SST_GAMMA=%2.1f",fxgamma);      // -> set gamma
-     putenv(gammastr);
-    }
-  }
-/*
- display=XOpenDisplay(NULL);                           // open display
- if(!display)                                          // no display?
-  {
-   fprintf (stderr,"Failed to open display!!!\n");
-   osd_close_display();
-   return;                                             // -> bye
-  }
+ 
+ // from nokia xlib+gl es examples
+ 
+ 
+ display = XOpenDisplay ( NULL );   // open the standard display (the primary screen)
+   if ( display == NULL ) {
+      printf( "cannot connect to X server\n" );
+   }
+ 
+   Window root  =  DefaultRootWindow( display );   // get the root window (usually the whole screen)
+ 
+   XSetWindowAttributes  swa;
+   swa.event_mask  =  ExposureMask | PointerMotionMask | KeyPressMask;
+ 
+   window  =  XCreateWindow (   // create a window with the provided parameters
+              display, root,
+              0, 0, 800, 480,   0,
+              CopyFromParent, InputOutput,
+              CopyFromParent, CWEventMask,
+              &swa );
+ 
+   XSetWindowAttributes  xattr;
+   Atom  atom;
+   int   one = 1;
+ 
+   xattr.override_redirect = False;
+   XChangeWindowAttributes ( display, window, CWOverrideRedirect, &xattr );
+ 
+   atom = XInternAtom ( display, "_NET_WM_STATE_FULLSCREEN", True );
+   XChangeProperty (
+      display, window,
+      XInternAtom ( display, "_NET_WM_STATE", True ),
+      XA_ATOM,  32,  PropModeReplace,
+      (unsigned char*) &atom,  1 );
+ 
+   XChangeProperty (
+      display, window,
+      XInternAtom ( display, "_HILDON_NON_COMPOSITED_WINDOW", True ),
+      XA_INTEGER,  32,  PropModeReplace,
+      (unsigned char*) &one,  1);
+ 
+   XWMHints hints2;
+   hints2.input = True;
+   hints2.flags = InputHint;
+   XSetWMHints(display, window, &hints2);
+ 
+   XMapWindow ( display , window );             // make the window visible on the screen
+   XStoreName ( display , window , "GL test" ); // give the window a name
+ 
+   //// get identifiers for the provided atom name strings
+   Atom wm_state   = XInternAtom ( display, "_NET_WM_STATE", False );
+   Atom fullscreen = XInternAtom ( display, "_NET_WM_STATE_FULLSCREEN", False );
+ 
+   XEvent xev;
+   memset ( &xev, 0, sizeof(xev) );
+ 
+   xev.type                 = ClientMessage;
+   xev.xclient.window       = window;
+   xev.xclient.message_type = wm_state;
+   xev.xclient.format       = 32;
+   xev.xclient.data.l[0]    = 1;
+   xev.xclient.data.l[1]    = fullscreen;
+   XSendEvent (                // send an event mask to the X-server
+      display,
+      DefaultRootWindow ( display ),
+      False,
+      SubstructureNotifyMask,
+      &xev );
+ 
+ 
+ 
+ //
+ 
+ eglDisplay  =  eglGetDisplay( (EGLNativeDisplayType) display );
+   if ( eglDisplay == EGL_NO_DISPLAY ) {
+      printf("Got no EGL display.\n" );
 
- myscreen=DefaultScreen(display);                      // get screen id
+   }
+ 
+   if ( !eglInitialize( eglDisplay, NULL, NULL ) ) {
+      printf("Unable to initialize EGL\n");
 
-#ifdef NOVMODE
- if(bFullScreen) {fx=1;bModeChanged=0;}
-#else
- if(bFullScreen)
-  {
-   XF86VidModeModeLine mode;
-   int nmodes,iC;
-   fx=1;                                               // raise flag
-   XF86VidModeGetModeLine(display,myscreen,&iC,&mode); // get actual mode info
-   if(mode.privsize) XFree(mode.private);              // no need for private stuff
-   bModeChanged=0;                                     // init mode change flag
-   if(iResX!=mode.hdisplay || iResY!=mode.vdisplay)    // wanted mode is different?
-    {
-     XF86VidModeGetAllModeLines(display,myscreen,      // -> enum all mode infos
-                                &nmodes,&modes);
-     if(modes)                                         // -> infos got?
-      {
-       for(iC=0;iC<nmodes;++iC)                        // -> loop modes
-        {
-         if(mode.hdisplay==modes[iC]->hdisplay &&      // -> act mode found?
-            mode.vdisplay==modes[iC]->vdisplay)        //    if yes: store mode id
-          iOldMode=iC;
+   }
+ 
+   EGLint attr[] = {       // some attributes to set up our egl-interface
+      EGL_BUFFER_SIZE, 16,
+      EGL_RENDERABLE_TYPE,
+      EGL_OPENGL_ES2_BIT,
+      EGL_NONE
+   };
+ 
+   EGLConfig  ecfg;
+   EGLint     num_config;
+   if ( !eglChooseConfig( eglDisplay, attr, &ecfg, 1, &num_config ) ) {
+      printf("Failed to choose config (eglError: \n");
 
-         if(iResX==modes[iC]->hdisplay &&              // -> wanted mode found?
-            iResY==modes[iC]->vdisplay)
-          {
-           XF86VidModeSwitchToMode(display,myscreen,   // --> switch to mode
-                                   modes[iC]);
-           XF86VidModeSetViewPort(display,myscreen,0,0);
-           bModeChanged=1;                             // --> raise flag for repairing mode on close
-          }
-        }
+   }
+ 
+   if ( num_config != 1 ) {
+      printf("Didn't get exactly one config, but \n");
 
-       if(bModeChanged==0)                             // -> no mode found?
-        {
-         free(modes);                                  // --> free infos
-         printf("No proper fullscreen mode found!\n"); // --> some info output
-        }
-      }
-    }
-  }
-#endif
+   }
+ 
+   eglSurface = eglCreateWindowSurface ( eglDisplay, ecfg, (void*)window, NULL );
+   if ( eglSurface== EGL_NO_SURFACE ) {
+      printf("Unable to create EGL surface (eglError\n");
 
+   }
+ 
+ 
+ GLint ctxattr[] = {
+      EGL_CONTEXT_CLIENT_VERSION, 2,
+      EGL_NONE
+   };
+   cx = eglCreateContext ( eglDisplay, ecfg, EGL_NO_CONTEXT, ctxattr );
+   if ( cx== EGL_NO_CONTEXT ) {
+      printf("Unable to create EGL context (eglError:\n");
+
+   }
+ 
+   //// associate the egl-context with the egl-surface
+
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+ 
+
+  /*
+  display=XOpenDisplay(NULL); 
+  
+ myscreen=DefaultScreen(display);  
  screen=DefaultScreenOfDisplay(display);
-
- if(iZBufferDepth)                                      // visual (with or without zbuffer)
-      myvisual=glXChooseVisual(display,myscreen,dbdepat);
- else myvisual=glXChooseVisual(display,myscreen,dbnodepat);
-*/
-
-	display = XOpenDisplay( 0 );
-
-	myscreen = XDefaultScreen( display );
+ 
 	
-	// Gets the window parameters
-	//sRootWindow = RootWindow(display, myscreen);
+
 	iColDepth = DefaultDepth(display, myscreen);
 	myvisual = new XVisualInfo;
 	XMatchVisualInfo( display, myscreen, iColDepth, TrueColor, myvisual);
 
 
-	
-	XMapWindow(display, window);
-	XFlush(display);
+//	XFlush(display);
 
-	/*
-		Step 1 - Get the default display.
-		EGL uses the concept of a "display" which in most environments
-		corresponds to a single physical screen. Since we usually want
-		to draw to the main screen or only have a single screen to begin
-		with, we let EGL pick the default display.
-		Querying other displays is platform specific.
-	*/
 
-	
-// =========
  if(!myvisual)                                         // no visual?
   {
    fprintf(stderr,"Failed to obtain visual!!!\n");     // -> bye
    osd_close_display();
    return;
   }
+*/
 
-  EGLConfig   iEglConfig;  
-  EGLint numConfigs;
+ /*
+
+ eglDisplay = eglGetDisplay((EGLNativeDisplayType)0);
  
- EGLint attribList [] = 
-{ 
-	EGL_BUFFER_SIZE, 0,  // color depth
-	EGL_DEPTH_SIZE, 15,  // z-buffer
-	EGL_NONE 
-};	
+EGLint iMajorVersion, iMinorVersion;
+	if (!eglInitialize(eglDisplay, &iMajorVersion, &iMinorVersion))
+	{
+		printf("Error: eglInitialize() failed.\n");
+
+	}
+
+	EGLint pi32ConfigAttribs[5];
+	pi32ConfigAttribs[0] = EGL_SURFACE_TYPE;
+	pi32ConfigAttribs[1] = EGL_WINDOW_BIT;
+	pi32ConfigAttribs[2] = EGL_RENDERABLE_TYPE;
+	pi32ConfigAttribs[3] = EGL_OPENGL_ES2_BIT;
+	pi32ConfigAttribs[4] = EGL_NONE;
+
+	EGLint pi32ContextAttribs[3];
+	pi32ContextAttribs[0] = EGL_CONTEXT_CLIENT_VERSION;
+	pi32ContextAttribs[1] = 2;
+	pi32ContextAttribs[2] = EGL_NONE;
+
+	int iConfigs;
+	if (!eglChooseConfig(eglDisplay, pi32ConfigAttribs, &eglConfig, 1, &iConfigs) || (iConfigs != 1))
+	{
+		printf("Error: eglChooseConfig() failed.\n");
+
+	}
+	 
+ //colormap=XCreateColormap(display,  RootWindow(display,myvisual->screen),     myvisual->visual,AllocNone);
  
+  eglSurface = eglCreateWindowSurface(
+        eglDisplay,
+        eglConfig,
+       (void*) window,
+        NULL);
+    if (EGL_NO_SURFACE == eglSurface)
+    {
+        printf("Failed to create EGL surface.\n");
 
+    }
 
-		attribList [1] = 16; 
+  
+TestEGLError("eglCreateWindowSurface");
 
-
-eglChooseConfig (display, attribList, &iEglConfig, 1, &numConfigs);
 	 
-	 
- cx=(EGLint*)eglCreateContext(display, iEglConfig, EGL_NO_CONTEXT, 0);    // create rendering context
+ cx= eglCreateContext(eglDisplay, eglConfig, NULL, pi32ContextAttribs);   // create rendering context
 
  if(!cx)                                               // no context?
   {
@@ -689,157 +798,27 @@ eglChooseConfig (display, attribList, &iEglConfig, 1, &numConfigs);
    return;
   }
 
- // pffff... much work for a simple blank cursor... oh, well...
- if(!bFullScreen) cursor=XCreateFontCursor(display,XC_trek);
- else
-  {
-   Pixmap p1,p2;XImage * img;
-   XColor b,w;unsigned char * idata;
-   XGCValues GCv;
-   GC        GCc;
-
-   memset(&b,0,sizeof(XColor));
-   memset(&w,0,sizeof(XColor));
-   idata=(unsigned char *)malloc(8);
-   memset(idata,0,8);
-
-   p1=XCreatePixmap(display,RootWindow(display,myvisual->screen),8,8,1);
-   p2=XCreatePixmap(display,RootWindow(display,myvisual->screen),8,8,1);
-
-   img = XCreateImage(display,myvisual->visual,
-                      1,XYBitmap,0,(char*)idata,8,8,8,1);
-
-   GCv.function   = GXcopy;
-   GCv.foreground = ~0;
-   GCv.background =  0;
-   GCv.plane_mask = AllPlanes;
-   GCc = XCreateGC(display,p1,
-                   (GCFunction|GCForeground|GCBackground|GCPlaneMask),&GCv);
-
-   XPutImage(display, p1,GCc,img,0,0,0,0,8,8);
-   XPutImage(display, p2,GCc,img,0,0,0,0,8,8);
-   XFreeGC(display, GCc);
-
-   cursor = XCreatePixmapCursor(display,p1,p2,&b,&w,0,0);
-
-   XFreePixmap(display,p1);
-   XFreePixmap(display,p2);
-   XDestroyImage(img);                                 // will free idata as well
-  }
-
- colormap=XCreateColormap(display,                     // create colormap
-                          RootWindow(display,myvisual->screen),
-                          myvisual->visual,AllocNone);
-
- winattr.background_pixel=0;
- winattr.border_pixel=WhitePixelOfScreen(screen);
- winattr.bit_gravity=ForgetGravity;
- winattr.win_gravity=NorthWestGravity;
- winattr.backing_store=NotUseful;
- winattr.override_redirect=False;
- winattr.save_under=False;
- winattr.event_mask=0;
- winattr.do_not_propagate_mask=0;
- winattr.colormap=colormap;
- winattr.cursor=None;
-
- window=XCreateWindow(display,                         // create own window
-             RootWindow(display,DefaultScreen(display)),
-             0,0,iResX,iResY,
-             0,myvisual->depth,
-             InputOutput,myvisual->visual,
-             CWBorderPixel | CWBackPixel |
-             CWEventMask | CWDontPropagate |
-             CWColormap | CWCursor,
-             &winattr);
-
- if(!window)                                           // no window?
-  {
-   fprintf(stderr,"Failed in XCreateWindow()!!!\n");
-   osd_close_display();                                // -> bye
-   return;
-  }
-
- delwindow = XInternAtom(display,"WM_DELETE_WINDOW",0);
- XSetWMProtocols(display, window, &delwindow, 1);
-
- hints.flags=PMinSize|PMaxSize;                        // hints
- if(fx) hints.flags|=USPosition|USSize;
- else   hints.flags|=PSize;
-
- hints.min_width   = hints.max_width  = hints.base_width  = iResX;
- hints.min_height  = hints.max_height = hints.base_height = iResY;
-
- wm_hints.input=1;
- wm_hints.flags=InputHint;
-
- XSetWMHints(display,window,&wm_hints);
- XSetWMNormalHints(display,window,&hints);
- if(pCaptionText)                                      // caption
-      XStoreName(display,window,pCaptionText);
- else XStoreName(display,window,"Pete MesaGL PSX Gpu");
-
- XDefineCursor(display,window,cursor);                 // cursor
-
- if(fx)                                                // window title bar hack
-  {
-   mwmhints.flags=MWM_HINTS_DECORATIONS;
-   mwmhints.decorations=0;
-   mwmatom=XInternAtom(display,"_MOTIF_WM_HINTS",0);
-   XChangeProperty(display,window,mwmatom,mwmatom,32,
-                   PropModeReplace,(unsigned char *)&mwmhints,4);
-  }
-
- XSelectInput(display,window,                          // input setup
-              FocusChangeMask | ExposureMask |
-              KeyPressMask | KeyReleaseMask);
-
- XMapRaised(display,window);
- XClearWindow(display,window);
- XWindowEvent(display,window,ExposureMask,&event);
-
+*/
  
- eglMakeCurrent (display, iEglSurface, iEglSurface, cx);
+ eglMakeCurrent (eglDisplay, eglSurface, eglSurface, cx);
 
+ /*
  printf((const char *)glGetString(GL_VENDOR));
  printf("\n");
  printf((const char *)glGetString(GL_RENDERER));
  printf("\n");
+*/
 
- if (fx)                                               // after make current: fullscreen resize
-  {
-   XResizeWindow(display,window,screen->width,screen->height);
-   hints.min_width   = hints.max_width = hints.base_width = screen->width;
-   hints.min_height= hints.max_height = hints.base_height = screen->height;
-   XSetWMNormalHints(display,window,&hints);
-
-   // set the window layer for GNOME
-   {
-    XEvent xev;
-
-    memset(&xev, 0, sizeof(xev));
-    xev.xclient.type = ClientMessage;
-    xev.xclient.serial = 0;
-    xev.xclient.send_event = 1;
-    xev.xclient.message_type = XInternAtom(display, "_NET_WM_STATE", 0);
-    xev.xclient.window = window;
-    xev.xclient.format = 32;
-    xev.xclient.data.l[0] = 1;
-    xev.xclient.data.l[1] = XInternAtom(display, "_NET_WM_STATE_FULLSCREEN", 0);
-    xev.xclient.data.l[2] = 0;
-    xev.xclient.data.l[3] = 0;
-    xev.xclient.data.l[4] = 0;
-
-    XSendEvent(display, RootWindow(display, DefaultScreen(display)), 0,
-      SubstructureRedirectMask | SubstructureNotifyMask, &xev);
-   }
-  }
+  
 }
 
 ////////////////////////////////////////////////////////////////////////
 
 long GPUopen(unsigned long * disp,char * CapText,char * CfgFile)
 {
+
+//window=GDK_WINDOW_XID( GTK_WIDGET( windowG )->window );
+
  pCaptionText=CapText;
  pConfigFile=CfgFile;
 
@@ -849,22 +828,28 @@ long GPUopen(unsigned long * disp,char * CapText,char * CfgFile)
 
  bIsFirstFrame = TRUE;                                 // we have to init later (well, no really... in Linux we do all in GPUopen)
 
+ printf ("Create GL objects\n");
  sysdep_create_display();                              // create display
 
+  printf ("Initialize textures\n");
  InitializeTextureStore();                             // init texture mem
 
  rRatioRect.left   = rRatioRect.top=0;
  rRatioRect.right  = iResX;
  rRatioRect.bottom = iResY;
-
+  printf ("Start GL\n");
+  
  GLinitialize();                                       // init opengl
 
+ printf ("Returning display\n");
  if(disp)
   {
    disp=(unsigned long *)display;                       // return display ID to main emu
   }
-
+printf ("Starting emu\n");
  if(display) return 0;
+ 
+ //gtk_widget_show_all (GTK_WIDGET (windowG));
  return -1;
 }
 
@@ -1283,10 +1268,10 @@ void updateDisplay(void)                               // UPDATE DISPLAY
    iDrawnSomething=0;                                  // -> simply lie about something drawn
   }
 
- if(iBlurBuffer && !bSkipNextFrame)                    // "blur display" activated?
-  {BlurBackBuffer();bBlur=TRUE;}                       // -> blur it
+// if(iBlurBuffer && !bSkipNextFrame)                    // "blur display" activated?
+//  {BlurBackBuffer();bBlur=TRUE;}                       // -> blur it
 
- if(iUseScanLines) SetScanLines();                     // "scan lines" activated? do it
+// if(iUseScanLines) SetScanLines();                     // "scan lines" activated? do it
 
  //if(usCursorActive) ShowGunCursor();                   // "gun cursor" wanted? show 'em
 
@@ -1315,7 +1300,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
    if(!bSkipNextFrame) 
     {
      if(iDrawnSomething)
-      eglSwapBuffers(display,iEglSurface);
+      eglSwapBuffers(eglDisplay,iEglSurface);
     }
    if(dwActFixes&0x180)                                // -> special old frame skipping: skip max one in a row
     {
@@ -1328,7 +1313,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
  else                                                  // no skip ?
   {
    if(iDrawnSomething)
-    eglSwapBuffers(display,iEglSurface);
+    eglSwapBuffers(eglDisplay,iEglSurface);
   }
 
  iDrawnSomething=0;
@@ -1354,7 +1339,7 @@ void updateDisplay(void)                               // UPDATE DISPLAY
   }
  else 
   {
-   if(bBlur) UnBlurBackBuffer();                       // unblur buff, if blurred before
+ //  if(bBlur) UnBlurBackBuffer();                       // unblur buff, if blurred before
 
    if(iZBufferDepth)                                   // clear zbuffer as well (if activated)
     {
@@ -1439,7 +1424,7 @@ void updateFrontDisplay(void)
 // if(ulKeybits&KEY_SHOWFPS) DisplayText();
 
  if(iDrawnSomething)                                   // linux:
-  eglSwapBuffers(display,iEglSurface);
+  eglSwapBuffers(eglDisplay,iEglSurface);
 
  //if(iBlurBuffer) UnBlurBackBuffer();
 }
