@@ -4,10 +4,11 @@
 #include <string.h>
 #include <pthread.h>
 #include <time.h>
+#include <libosso.h>
+#include <dbus/dbus.h>
 
 #include "minimal.h"
 
-
 GdkImage *image;
 HildonAnimationActor *actor;
 GtkWidget *window, *drawing;
@@ -22,6 +23,8 @@ GtkWidget* windowG;
 int screen_size;
 unsigned short* screenbuffer = NULL;
 
+osso_context_t* osso;
+unsigned int state_slot = 0;
 
 unsigned long keys = 0;
 pthread_t accel;
@@ -40,6 +43,25 @@ void hildon_quit()
 	exit(0);
 }
 
+void show_notification(char* text)
+{
+	DBusConnection* session_bus = (DBusConnection*)osso_get_dbus_connection(osso);
+	DBusMessageIter args;
+	DBusMessage*msg = dbus_message_new_method_call("org.freedesktop.Notifications", 
+												   "/org/freedesktop/Notifications",
+												   "org.freedesktop.Notifications", 
+												   "SystemNoteInfoprint");
+	if (msg) { 
+		dbus_message_iter_init_append(msg, &args);
+		char* param = text;
+		if (dbus_message_iter_append_basic(&args, DBUS_TYPE_STRING, &param)) {
+			dbus_connection_send(session_bus, msg, NULL);
+			dbus_connection_flush(session_bus);
+		}
+		dbus_message_unref(msg);
+	}
+}
+
 static void
 window_key_proxy (GtkWidget *widget,
 		     GdkEventKey *event,
@@ -117,13 +139,35 @@ switch(keymap[event->hardware_keycode]){
 		key = -1;			return ;			break;
 	case 19:
 		SaveState(cfile);
+		char message[50];
+		sprintf(message,"Saved savestate slot: %i",state_slot + 1);
+		show_notification(message);
 		key = -1;			return ;			break;
 	break;
 	case 20:
 		LoadState(cfile);
 		key = -1;			return ;			break;
 	break;
-}
+	case 21:
+		if (event->type == GDK_KEY_PRESS){
+			state_slot=(state_slot<9)?state_slot+1:0;
+			//"%.32s-%.9s.%3.3d"
+			sprintf (cfile, "%s.save.%i", file, state_slot);
+			char message[50];
+			sprintf(message,"Savestate slot: %i",state_slot + 1);
+			show_notification(message);
+		}
+		key = -1;			return ;			break;
+	case 22:
+		if (event->type == GDK_KEY_PRESS){
+			state_slot=(state_slot>0)?state_slot-1:9;
+			sprintf (cfile, "%s.save.%i", file, state_slot);
+			char message[50];
+			sprintf (message,"Savestate slot: %i",state_slot + 1);
+			show_notification(message);
+		}
+		key = -1;			return ;			break;
+	}
 	
 	if (event->type == GDK_KEY_PRESS) {
 		keys |= key;
@@ -137,10 +181,14 @@ switch(keymap[event->hardware_keycode]){
 
 void hildon_init2(int *argc, char ***argv,char *fl,char* lst,bool fscreen)
 {
-fullscreen=fscreen;
+	fullscreen=fscreen;
+
+	osso = osso_initialize("psx4m", "1.0", FALSE, NULL);
+	state_slot = lst ? atol(lst) - 1: 0;
+
 	file=fl;
 	cfile=new char[255];
-	sprintf (cfile, "%s.save.%s", file,lst);
+	sprintf (cfile, "%s.save.%i", file, state_slot);
 	if (Config.PsxOut)printf ("Save file:%s\n",cfile);
 	//cfile="/home/opt/psx4m/savestate";
 	
@@ -153,7 +201,7 @@ fullscreen=fscreen;
 	for (int i=0;i<65536;i++)
 		keymap[i]=164;
 	if (NULL != pFile) {
-		for(int i=0;i<21;i++){
+		for(int i=0;i<23;i++){
 			fscanf(pFile, "%i",&ch);
 			keymap[ch]=i;
 		}
